@@ -6,17 +6,18 @@ use List::Util;
 use Data::Dumper qw(Dumper);
 use Exporter qw(import);
 our @EXPORT_OK = qw(
-    incr         reduces  flatten
+    incr        reduces  flatten
     drop_right  drop     take_right  take
-    assoc       maps     decr         chain
-    first       end   subarray    partial
+    assoc       maps     decr        chain
+    first       end      subarray    partial
     __          find     filter      some
     none        uniq     bool        spread
     len         to_keys  to_vals     is_array
     is_hash     every    noop        identity
+    is_empty    flow
 );
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use constant ARG_PLACE_HOLDER => {};
 
@@ -32,6 +33,19 @@ sub identity {
     return $args;
 }
 
+sub flow {
+    my $args = [@_];
+
+    if (ref $args->[0] ne 'CODE') {
+        carp("Expected a function as first argument");
+    }
+
+    return sub {
+        my $start_value = shift // noop;
+        chain($start_value, spread($args));
+    }
+}
+
 sub is_array {
     my $coll       = shift;
     my $extra_args = [@_];
@@ -426,12 +440,13 @@ concise code.
 
     incr        reduces  flatten
     drop_right  drop     take_right  take
-    assoc       maps     decr         chain
+    assoc       maps     decr        chain
     first       end      subarray    partial
     __          find     filter      some
     none        uniq     bool        spread
     len         to_keys  to_vals     is_array
     is_hash     every    noop        identity
+    flow
 
 =cut
 
@@ -711,6 +726,33 @@ Returns 0 or 1 if the argument is a hash
 
 =cut
 
+=head2 is_empty
+
+Returns 1 if the argument is 'empty',
+0 if not empty. Used on strings, arrays, hashes.
+
+    is_empty()
+
+    # 1
+
+    is_empty([])
+
+    # 1
+
+    is_empty([1,2,3])
+
+    # 0
+
+    is_empty({ key => 'val' })
+
+    # 0
+
+    is_empty("I am a string")
+
+    # 0
+
+=cut
+
 =head2 spread
 
 Destructures an array / hash into non-ref context.
@@ -1037,6 +1079,19 @@ as the first argument to the proceding function
 
 =cut
 
+=head2 flow
+
+Creates a function that returns the result of invoking the given functions,
+where each successive invocation is supplied the return value of the previous.
+
+    my $addTwo = flow(\&incr, \&incr);
+
+    $addTwo->(1);
+
+    # 3
+
+=cut
+
 =head1 AUTHOR
 
 Kristopher C. Paulsen, C<< <kristopherpaulsen+cpan at gmail.com> >>
